@@ -1,6 +1,6 @@
 package DateTime::Duration;
 {
-  $DateTime::Duration::VERSION = '0.74';
+  $DateTime::Duration::VERSION = '0.76';
 }
 
 use strict;
@@ -318,7 +318,7 @@ DateTime::Duration - Duration objects for date math
 
 =head1 VERSION
 
-version 0.74
+version 0.76
 
 =head1 SYNOPSIS
 
@@ -374,12 +374,12 @@ version 0.74
 This is a simple class for representing duration objects. These
 objects are used whenever you do date math with DateTime.pm.
 
-See the L<How Date Math is Done|DateTime/"How Date Math is Done">
-section of the DateTime.pm documentation for more details. The short
-course:  One cannot in general convert between seconds, minutes, days,
-and months, so this class will never do so. Instead, create the
-duration with the desired units to begin with, for example by calling
-the appropriate subtraction/delta method on a C<DateTime.pm> object.
+See the L<How DateTime Math Works|DateTime/"How DateTime Math Works"> section
+of the DateTime.pm documentation for more details. The short course: One
+cannot in general convert between seconds, minutes, days, and months, so this
+class will never do so. Instead, create the duration with the desired units to
+begin with, for example by calling the appropriate subtraction/delta method on
+a C<DateTime.pm> object.
 
 =head1 METHODS
 
@@ -460,7 +460,7 @@ conversions possible are:
 
 =back
 
-For the explanation of why this is the case, please see the L<How Datetime
+For the explanation of why this is the case, please see the L<How DateTime
 Math Works|DateTime/"How DateTime Math Works"> section of the DateTime.pm
 documentation
 
